/* ssl_null.h */
/* Copyright (C) 1995 Eric Young (eay@mincom.oz.au).
 * All rights reserved.
 * Copyright remains Eric Young's, and as such any Copyright notices in
 * the code are not to be removed.
 * See the COPYRIGHT file in the SSLeay distribution for more details.
 */

typedef struct null_state_st
	{
	unsigned char a[8];
	unsigned char b[8];
	} NULL_STATE;

#ifdef PROTO
int ssl_enc_null_init(SSL *s, int client);
void ssl_enc_null(SSL *s);
void ssl_compute_null_mac(SSL *s, char *md);
#else
int ssl_enc_null_init();
void ssl_enc_null();
void ssl_compute_null_mac();
#endif
